<?php
//////////////////////////////////////////////////////////////////////////////////
//    					 copyright (c) Arfooo Annuaire                          //
//   				 by Hocine Guillaume (c) 2007 - 2008                        //
//       					http://www.arfooo.com/                              //
//    Licence Creative Commons http://creativecommons.org/licenses/by/2.0/fr/   //
//////////////////////////////////////////////////////////////////////////////////

class Moderation_SiteController extends Controller
{ 
    function init()
    {        
        $this->acl->allow('moderator', $this->name, "*");
        $this->acl->allow('administrator', $this->name, "*");
        
        if(!$this->acl->isAllowed($this->session->get("role"), $this->name, $this->action))
        {
            $this->redirect(FrontController::getRewrittedUrl("/moderation/main/logIn"));  
        }
    }
    
    function indexAction()
    {                    
        $this->redirect($this->moduleLink("waiting"));
    }
    
    function waitingAction()
    {
        $this->set("sites", $this->site->getWaitingSites()); 
    }
    
    function getMetaDataAction()
    {
        $httpClient = new HttpClient();
        $metaData = $httpClient->getMetaValues($this->request->url);
        $this->set($metaData);
        $this->viewClass = "JsonView";    
    }
    
    function getWebsiteDataAction()
    {
        $siteId = $this->request->siteId;
        $site = $this->site->findByPk($siteId);
        
        if($site->status == "waiting")
        {
            $site->keywordIds = $site->getKeywordIds();   
            $this->set($site->toArray());
        }
        
        $this->viewClass = "JsonView";
    }
    
    function getWebmasterDataAction()
    {
        $c = new Criteria();
        $c->add("userId", $this->request->webmasterId);
        $c->add("role", "webmaster");
        $site = $this->user->find($c, "login, email");  
        $this->set($site->toArray());
        $this->viewClass = "JsonView";
    }

    function editAction($siteId)
    {   
        $c = new Criteria();
        $c->add("status", "waiting");
        $c->add("siteId", $siteId);
        
        $site = $this->site->find($c);
        if(empty($site))$this->redirect($this->moduleLink("waiting"));
    
        $this->set("siteId", $siteId);
        
        $site->updateImageSrc();
        $this->set("site", $site);
        
        $c = new Criteria();
        $c->add("siteId", $siteId);
        $this->set("comments", $this->comment->findAll($c));
        
        $this->set("selectCategories", $this->category->createOptionsList());
        $c = new Criteria();
        $c->add("role", "webmaster");
        $this->set("webmasters", $this->user->generateList($c, "email"));
        
        $this->set("allKeywordsList", $this->keyword->generateList(null, "keyword"));
        $this->set("yesNoOptions", array("0" => _t("No"), "1" => _t("Yes")));
        $this->set("statusOptions", array("validated" => _t("No"), "banned" => _t("Yes"))); 
        $this->set("priorites", range(0, 10));
        
        $this->set("adCriterias", $this->adCriteria->getSelectList()); 

    }
    
    function updateSiteStateAction()
    {
        if(!empty($this->request->siteIds)
        && in_array($this->request->status, array("validated", "banned", "refused")))
        {
            $siteIds = $this->request->siteIds;
            $status = $this->request->status;
            
            $mailer = Mailer::getInstance();
            
            $c = new Criteria();
            $c->add("status", "waiting");
            $c->add("siteId", $siteIds, "IN");
            $sites = $this->site->findAll($c, "*", true);

            foreach($sites as $site)
            { 
                $site['status'] = $status;
                $customSubject = false;
                $customDescription = false;
                $siteId = $site['siteId'];
                
                if($this->request->emailType[$siteId] == "custom")
                {
                    $customSubject = $this->request->subject[$siteId];
                    $customDescription = $this->request->description[$siteId];
                }
                
                $mailer->sendSiteStateUpdate($site['webmasterEmail'], $site, $customSubject, $customDescription);      
            }
                
            if($status == "refused")
            {
                $this->site->del($c);
                $this->refusal->updateRefusedSitesCount(0, count($sites)); 
            }
            else
            {
                $this->site->update(array("status" => $status, "moderatorId" => $this->userId), $c);
            }
        }
                       
        $this->redirect($this->moduleLink("waiting"));        
    }
    
    function saveSiteDataAction($siteId)
    {
        $c = new Criteria();
        $c->add("status", "waiting");
        $c->add("siteId", $siteId);
        
        $site = $this->site->find($c);
        if(empty($site))$this->redirect($this->moduleLink("waiting"));
        
        $this->viewClass = "JsonView";
        
        $fields = array("categoryId", "webmasterName", "webmasterEmail", "siteTitle", "url", "rssTitle", "rssFeedOfSite",
                        "description", "returnBond", "status", "problemExists", "priority");

        $data = $this->request->getArray($fields);
        
        $errorMessage = $this->site->validate($this->request, $site);

        if($errorMessage)
        {
            $this->set("message", $errorMessage);
            $this->set("status", "error");
            return;
        }
        
        $site->fromArray($data);
        
        $site->description = substr($site->description, 0, Config::get('siteDescriptionMaxLength'));       
        $site->save();

        // store keywords
        if(!empty($this->request->keywords))
        {
            $this->keywordsOfSite->storeKeywords($site->siteId, $this->request->keywords);
        }
        
        $this->set("message", "Updated");
        $this->set("status", "ok");
    }
    
    function uploadSiteImageAction($siteId)
    {
        $siteId = intval($siteId);
        $site = $this->site->findByPk($siteId);
        
        $siteImage = new UploadedFile("siteImage");
        $siteImage->addFilter("extension", array("jpg", "png", "gif"));
        $thumbsPath = Config::get("SITES_THUMBS_PATH");
        $newImageSrc = $siteImage->save($thumbsPath);
        
        if($newImageSrc)
        {
            if($site->imageSrc)
            {
                $oldFilePath = $thumbsPath . basename($site->imageSrc);
                
                if(file_exists($oldFilePath))
                {
                    unlink($oldFilePath);
                }
            }
            
            $site->imageSrc = $newImageSrc;
            $site->save();
        }
        
        $site->updateImageSrc();
        
        echo "<html><body>".$site->imageSrc."</body></html>";
        $this->autoRender = false;
    }
    
    function getWaitingSitesHtmlAction()
    {
        $siteIds = explode(",", $this->request->siteIds);
        $c = new Criteria();
        $c->add("status", "waiting");
        $this->set("sites", $this->site->getWaitingSites($siteIds));
        $this->viewFile = "item";
    }
    
    function compareWaitingSitesAction()
    {
        $waitingSitesOnHtml = $this->request->waitingSitesIds ? explode(",", $this->request->waitingSitesIds) : array();       

        $c = new Criteria();
        $c->add("status", "waiting");
        $sites = $this->site->generateList($c, "siteId");

        $actualWaitingSitesInDb = array_values($sites);

        $sitesToRemove = array_diff($waitingSitesOnHtml, $actualWaitingSitesInDb);
        $sitesToAdd = array_diff($actualWaitingSitesInDb, $waitingSitesOnHtml);

        $this->set("toRemove", array_values($sitesToRemove));
        $this->set("toAdd", array_values($sitesToAdd));
        $this->set("waiting", array_values($actualWaitingSitesInDb));
        
        $this->viewClass = "JsonView";

    }
} 

?>